/* -------------------------------------------------------------------

This file defines the problem dependent data structures for the Electrode problem.

getdp EleMuscCyl09 -solve EleKin_v -pos Map

------------------------------------------------------------------- */
Include "PhysicalValue.dat" 


Group {
	ELEC1 = Region[1000];
	ELEC2 = Region[1001];
	ELEC3 = Region[1002];
	MUSCLE = Region[2000]; 
	POINTREF = Region[3000];
	DomainC_Ele = Region[{MUSCLE}];

	// Only 2 electrodes (e.g. ELEC2,ELEC3) are included in Region Electrode;
	// a reference potential will be fixed on the 3rd electrode (ELEC1)
	// (global quantities will be defined -> increase the 'Nb_Fill' parameter in solver.par to e.g. 200)

	Electrode = Region[{ELEC2,ELEC3}] ;
	Electrode_j = Region[{}] ;

	// Another way to define the problem can be done with (instead of the previous definition, to be commentarized):
	/*
	Electrode = Region[{}] ;
	Electrode_j = Region[{ELEC1,ELEC2,ELEC3}] ;
	*/
	// In this case, do not forget to commentarize '{ Region ELEC1; Value 0.; }' in ElectricScalarPotential Constraint
	// and to define '{ Region POINTREF; Value 0.; }' in the same Constraint (to fix the potential at one node, 
	// for a rigorous treatment in the absence of any other Dirichlet condition).

}

/*******************************************************************
 The conductivity (needed in the formulation) is piecewise
defined in elementary groups 
********************************************************************/
SigMUSCLE = 1/5.0 ;
Function { Sig[MUSCLE] = SigMUSCLE ; }

Function { j[ELEC1] = J1 ; j[ELEC2] = J2 ; j[ELEC3] = J3 ;}
// Only used if ELEC1, ELEC2 and ELEC3 are in Region Electrode_j. In this case, the distribution of the current density
// must be given. This distribution is usually not known in advance and should rather be the solution of the problem. For
// that, it is better to fix the total current through each electrode (here through 2 of them, the 3rd one supporting a
// reference potential.
// The given current density is actually the normal current density leaving the studied domain. Nothing is fixed regarding
// its tangential component, which explains the non-perpendicularity of the current density to the electrodes.
// To force the perpendicularity, each electrode has to support a constant potential (of floating nature). The associated
// global quantity will then be the current through each electrode.

/*******************************************************************
 Now, some Dirichlet conditions are defined. The name
ElectricScalarPotential refers to the constraint name given in
the function space 
*******************************************************************/

Constraint {
  { Name ElectricScalarPotential; Type Assign;
    Case {
      { Region ELEC1; Value 0.; } // Reference electric potential
      //      { Region POINTREF; Value 0.; }
    }
  }

  { Name GlobalElectricPotential; Type Assign;
    Case {
    }
  }

  { Name GlobalElectricCurrent; Type Assign;
    Case { // Currents going out of the studied domain
      { Region ELEC2; Value -I21; }
      { Region ELEC3; Value I13; }
    }
  }
}


/*Constraint {
	{ Name ElectricScalarPotential; Type Assign;
		Case 	{
		{ Region ElecPot0; Value 0; }
		{ Region ElecPot1; Value VElecPot1; }
		{ Region ElecPot2; Value VElecPot2; }
		{ Region ElecPot3; Value VElecPot3; }
		{ Region ElecPot4; Value VElecPot4; }
		{ Region ElecPot5; Value VElecPot5; }
			}
	}
}*/

/*******************************************************************
 The formulation used and its tools, considered as being
in a black box, can now be included 
*******************************************************************/

Length = 2.*Pi; // For an axisymmetrical problem (otherwise, length of the structure)

Include "Jac_EleMuscCyl.pro"
Include "Int_EleMuscCyl.pro"
Include "EleKin_EleMuscCyl.pro"
 



/*******************************************************************
 Finally, we can define some operations to output results 
*******************************************************************/
PostOperation {
	{ Name Map; NameOfPostProcessing EleKin_v;
		Operation 	{
			Print [ v, OnElementsOf DomainC_Ele, File "ElecMusc_v.pos" ];
			Print [ j, OnElementsOf DomainC_Ele, File   "ElecMusc_j.pos"];
			Print [ j, OnElementsOf MUSCLE, Skin, File   "ElecMusc_jskin.pos"];
			/*Print [ jabs, OnElementsOf DomainC_Ele, File "ElecMusc_jabs.pos",Format GmshParsed ];*/
			Print [ jabs, OnElementsOf DomainC_Ele, File "ElecMusc_jabs.pos" ];
			/*Echo [ "View[4].CustomMax = 210;", File >> "ElecMusc_jabs.pos" ];*/
			/*Print [ jabs, OnGrid ElecJCenterEdge, File "ElecMusc_ElecJCenterEdge.pos"];*/
			/*Print [ jabs, OnLine {{0.0,-0.0113,0} {0.025,-0.0113,0}} {2} , File "ElecMusc_ElecJCenterEdge.pos"];*/

				}
	}
	
	{ Name Current; NameOfPostProcessing EleKin_v;
		Operation 	{
			Print [ I, OnRegion Electrode ];
			Print [ V, OnRegion Electrode ];
				}
	}
	
}

/*Include "post.pos"*/
